qadevOOo/tests/java/ifc/text/_XTextContent.java             |    2 +-
 qadevOOo/tests/java/ifc/text/_XTextRangeCompare.java        |    4 ++--
 qadevOOo/tests/java/ifc/ucb/_XContentIdentifierFactory.java |    2 +-
 qadevOOo/tests/java/ifc/ui/_XUIConfiguration.java           |    2 +-
 qadevOOo/tests/java/ifc/util/_XStringSubstitution.java      |    4 ++--
 qadevOOo/tests/java/ifc/view/_XScreenCursor.java            |    2 +-
 qadevOOo/tests/java/mod/_defreg/NestedRegistry.java         |    4 ++--
 qadevOOo/tests/java/mod/_fwk/JobExecutor.java               |    2 +-
 qadevOOo/tests/java/mod/_fwk/JobHandler.java                |    2 +-
 qadevOOo/tests/java/mod/_fwk/ModuleManager.java             |    2 +-
 qadevOOo/tests/java/mod/_nestedreg/uno/NestedRegistry.java  |    4 ++--
 qadevOOo/tests/java/mod/_sc/ScTabViewObj.java               |    6 +++---
 qadevOOo/tests/java/mod/_sch/ChXDiagram.java                |    2 +-
 registry/source/keyimpl.cxx                                 |    2 +-
 14 files changed, 20 insertions(+), 20 deletions(-)

New commits:
commit ca6df519a78e5bfc96030c916f242b86306194e5
Author:     Andrea Gelmini <andrea.gelm...@gelma.net>
AuthorDate: Tue Jul 30 08:03:32 2019 +0200
Commit:     Andrea Gelmini <andrea.gelm...@gelma.net>
CommitDate: Tue Jul 30 23:47:47 2019 +0200

    Fix typos
    
    Change-Id: Ia5fba032635adbf85bdfcb1eb0b3ffb9cf9d4a6a
    Reviewed-on: https://gerrit.libreoffice.org/76548
    Reviewed-by: Julien Nabet <serval2...@yahoo.fr>
    Tested-by: Andrea Gelmini <andrea.gelm...@gelma.net>

diff --git a/qadevOOo/tests/java/ifc/text/_XTextContent.java 
b/qadevOOo/tests/java/ifc/text/_XTextContent.java
index 3b6a5e0a4578..bcb65b806343 100644
--- a/qadevOOo/tests/java/ifc/text/_XTextContent.java
+++ b/qadevOOo/tests/java/ifc/text/_XTextContent.java
@@ -52,7 +52,7 @@ public class _XTextContent extends MultiMethodTest {
     /**
      * Tries to get the anchor of the text content
      * an XTextRange is returned. <p>
-     * The test is OK if an not null text range is returned
+     * The test is OK if a not null text range is returned
      */
     public void _getAnchor() {
         log.println("getAnchor()");
diff --git a/qadevOOo/tests/java/ifc/ucb/_XContentIdentifierFactory.java 
b/qadevOOo/tests/java/ifc/ucb/_XContentIdentifierFactory.java
index d129579e1ff4..6a66dae9ee63 100644
--- a/qadevOOo/tests/java/ifc/ucb/_XContentIdentifierFactory.java
+++ b/qadevOOo/tests/java/ifc/ucb/_XContentIdentifierFactory.java
@@ -43,7 +43,7 @@ public class _XContentIdentifierFactory extends 
MultiMethodTest {
     /**
      * Calls the tested method with a file url and
      * gets an identifier. <p>
-     * Has <b> OK </b> status if content identifier an provider sheme are
+     * Has <b> OK </b> status if content identifier and provider scheme are
      * proper. <p>
      */
     public void _createContentIdentifier() {
diff --git a/qadevOOo/tests/java/ifc/ui/_XUIConfiguration.java 
b/qadevOOo/tests/java/ifc/ui/_XUIConfiguration.java
index 8b880e67cf7c..73290288c89c 100644
--- a/qadevOOo/tests/java/ifc/ui/_XUIConfiguration.java
+++ b/qadevOOo/tests/java/ifc/ui/_XUIConfiguration.java
@@ -63,7 +63,7 @@ public class _XUIConfiguration extends MultiMethodTest {
     }
 
     /**
-     * adds a listener an fire an event
+     * adds a listener and fires an event
      * Has <B>OK</B> status if listener was called
      */
     public void _addConfigurationListener() {
diff --git a/qadevOOo/tests/java/ifc/util/_XStringSubstitution.java 
b/qadevOOo/tests/java/ifc/util/_XStringSubstitution.java
index a19ecbaf467c..77d5fe5fbb43 100644
--- a/qadevOOo/tests/java/ifc/util/_XStringSubstitution.java
+++ b/qadevOOo/tests/java/ifc/util/_XStringSubstitution.java
@@ -37,7 +37,7 @@ public class _XStringSubstitution extends MultiMethodTest {
             tRes.tested("getSubstituteVariableValue()",false);
         }
         try {
-            log.println("try to get a invalid variable...");
+            log.println("try to get an invalid variable...");
             String toCheck = "$(ThisVariableShouldNoExist)";
             oObj.getSubstituteVariableValue(toCheck);
             log.println("$(ThisVariableShouldNoExist) should not exist");
@@ -64,7 +64,7 @@ public class _XStringSubstitution extends MultiMethodTest {
             tRes.tested("substituteVariables()",false);
         }
         try {
-            log.println("try to get a invalid variable...");
+            log.println("try to get an invalid variable...");
             String toCheck = "$(ThisVariableShouldNoExist)";
             oObj.substituteVariables(toCheck,true);
             log.println("$(ThisVariableShouldNoExist) should not exist");
diff --git a/qadevOOo/tests/java/ifc/view/_XScreenCursor.java 
b/qadevOOo/tests/java/ifc/view/_XScreenCursor.java
index 3f28462dc17c..aad7257e36d9 100644
--- a/qadevOOo/tests/java/ifc/view/_XScreenCursor.java
+++ b/qadevOOo/tests/java/ifc/view/_XScreenCursor.java
@@ -64,7 +64,7 @@ public class _XScreenCursor extends MultiMethodTest {
      * The following method tests are to be completed successfully before :
      * <ul>
      *  <li> <code> screenDown() </code> : by default view is on the
-     *  top of pag, thereby its needed first to moved down. </li>
+     *  top of page, thereby it's needed first to move down. </li>
      * </ul>
      */
     public void _screenUp(){
diff --git a/qadevOOo/tests/java/mod/_defreg/NestedRegistry.java 
b/qadevOOo/tests/java/mod/_defreg/NestedRegistry.java
index ab13aa4c9467..a571c7e2c032 100644
--- a/qadevOOo/tests/java/mod/_defreg/NestedRegistry.java
+++ b/qadevOOo/tests/java/mod/_defreg/NestedRegistry.java
@@ -80,7 +80,7 @@ public class NestedRegistry extends TestCase {
     * Creates a temporary copy of file, which is deleted when VM exits.
     * @param src Source file path.
     * @param dst Destination file path.
-    * @throws java.io.IOException If any problems occur during copiing.
+    * @throws java.io.IOException If any problems occur during copying.
     */
     protected void copyFile(String src, String dst, PrintWriter log)
             throws java.io.IOException {
@@ -125,7 +125,7 @@ public class NestedRegistry extends TestCase {
     * <ul>
     *  <li> <code>'NR'</code> for {@link ifc.registry._XSimpleRegistry} :
     *     Just informs interface test that <code>NestedRegistry</code>
-    *     service is tested. If this relation exists, than some methods
+    *     service is tested. If this relation exists, then some methods
     *     are not supported. The relation is a <code>String</code> with
     *     object name.</li>
     *  <li> <code>'XSimpleRegistry.open'</code> for
diff --git a/qadevOOo/tests/java/mod/_fwk/JobExecutor.java 
b/qadevOOo/tests/java/mod/_fwk/JobExecutor.java
index 7390e2c426f4..61dee42e9469 100644
--- a/qadevOOo/tests/java/mod/_fwk/JobExecutor.java
+++ b/qadevOOo/tests/java/mod/_fwk/JobExecutor.java
@@ -106,7 +106,7 @@ public class JobExecutor extends TestCase {
             Param.getMSF().createInstance("test.Job");
         } catch(com.sun.star.uno.Exception e) {
             log.println("Service test.Job is not yet registered.");
-            String message = "You have to register 'test.Job' before office is 
stared.\n";
+            String message = "You have to register 'test.Job' before office is 
started.\n";
             message += "Please run '$OFFICEPATH/program/pkgchk 
$DOCPTH/qadevlibs/JobExecutor.jar'";
             throw new StatusException(message, e);
         }
diff --git a/qadevOOo/tests/java/mod/_fwk/JobHandler.java 
b/qadevOOo/tests/java/mod/_fwk/JobHandler.java
index 750a04adf69a..ed86cfb739a7 100644
--- a/qadevOOo/tests/java/mod/_fwk/JobHandler.java
+++ b/qadevOOo/tests/java/mod/_fwk/JobHandler.java
@@ -56,7 +56,7 @@ public class JobHandler extends TestCase {
         log.println("Service test.Job is "
             + (serviceRegistered ? "already" : "not yet")  + " registered.");
         if (! serviceRegistered){
-            String message = "You have to register 'test.Job' before office is 
stared.\n";
+            String message = "You have to register 'test.Job' before office is 
started.\n";
             message += "Please run '$OFFICEPATH/program/pkgchk 
$DOCPTH/qadevlibs/JobExecutor.jar'";
             throw new StatusException(message, new Exception());
         }
diff --git a/qadevOOo/tests/java/mod/_fwk/ModuleManager.java 
b/qadevOOo/tests/java/mod/_fwk/ModuleManager.java
index 655ef3ffb6b5..a700bffaf8a0 100644
--- a/qadevOOo/tests/java/mod/_fwk/ModuleManager.java
+++ b/qadevOOo/tests/java/mod/_fwk/ModuleManager.java
@@ -116,7 +116,7 @@ public class ModuleManager extends TestCase {
         XFrame xDrawFrame = xDrawController.getFrame();
 
         // get impress interfaces
-        log.println("creating a impress document");
+        log.println("creating an impress document");
         xImpressDoc = SOF.createImpressDoc(null);
         XModel xImpressMode1 = UnoRuntime.queryInterface(XModel.class,
                                                        xImpressDoc);
diff --git a/qadevOOo/tests/java/mod/_nestedreg/uno/NestedRegistry.java 
b/qadevOOo/tests/java/mod/_nestedreg/uno/NestedRegistry.java
index d31137dfbc72..b546d56d44a0 100644
--- a/qadevOOo/tests/java/mod/_nestedreg/uno/NestedRegistry.java
+++ b/qadevOOo/tests/java/mod/_nestedreg/uno/NestedRegistry.java
@@ -78,7 +78,7 @@ public class NestedRegistry extends TestCase {
     * Creates a temporary copy of file, which is deleted when VM exits.
     * @param src Source file path.
      * @param dst Destination file path.
-    * @throws java.io.IOException If any problems occur during copiing.
+    * @throws java.io.IOException If any problems occur during copying.
     */
     protected void copyFile(String src, String dst)
             throws java.io.IOException {
@@ -122,7 +122,7 @@ public class NestedRegistry extends TestCase {
     * <ul>
     *  <li> <code>'NR'</code> for {@link ifc.registry._XSimpleRegistry} :
     *     Just informs interface test that <code>NestedRegistry</code>
-    *     service is tested. If this relation exists, than some methods
+    *     service is tested. If this relation exists, then some methods
     *     are not supported. The relation is a <code>String</code> with
     *     object name.</li>
     *  <li> <code>'XSimpleRegistry.open'</code> for
diff --git a/qadevOOo/tests/java/mod/_sc/ScTabViewObj.java 
b/qadevOOo/tests/java/mod/_sc/ScTabViewObj.java
index f1e79ed4904b..a00b2724d80f 100644
--- a/qadevOOo/tests/java/mod/_sc/ScTabViewObj.java
+++ b/qadevOOo/tests/java/mod/_sc/ScTabViewObj.java
@@ -211,11 +211,11 @@ public class ScTabViewObj extends TestCase {
                 try {
                     myForm = (XForm) AnyConverter.toObject(new 
Type(XForm.class),xForm.getByName("Standard"));
                 } catch (WrappedTargetException ex) {
-                    log.println("ERROR: could not XFormm 'Standard': " + 
ex.toString());
+                    log.println("ERROR: could not XForm 'Standard': " + 
ex.toString());
                 } catch (com.sun.star.lang.IllegalArgumentException ex) {
-                    log.println("ERROR: could not XFormm 'Standard': " + 
ex.toString());
+                    log.println("ERROR: could not XForm 'Standard': " + 
ex.toString());
                 } catch (NoSuchElementException ex) {
-                    log.println("ERROR: could not XFormm 'Standard': " + 
ex.toString());
+                    log.println("ERROR: could not XForm 'Standard': " + 
ex.toString());
                 }
                 if (myForm == null)
                     log.println("ERROR: could not get XForm: null");
diff --git a/qadevOOo/tests/java/mod/_sch/ChXDiagram.java 
b/qadevOOo/tests/java/mod/_sch/ChXDiagram.java
index 78e5c4a5cdb5..c9433e6b9924 100644
--- a/qadevOOo/tests/java/mod/_sch/ChXDiagram.java
+++ b/qadevOOo/tests/java/mod/_sch/ChXDiagram.java
@@ -338,7 +338,7 @@ public class ChXDiagram extends TestCase {
     } // finish method getTestEnvironment
 
     /**
-    * Inserts a value or a formula in the cell of the spreasheet.
+    * Inserts a value or a formula in the cell of the spreadsheet.
     * @param CellX is the column index of the cell
     * @param CellY is the row index of the cell
     * @param theValue string representation of the value
diff --git a/registry/source/keyimpl.cxx b/registry/source/keyimpl.cxx
index 702a380038a1..e5aef0675199 100644
--- a/registry/source/keyimpl.cxx
+++ b/registry/source/keyimpl.cxx
@@ -696,7 +696,7 @@ RegError ORegKey::getLongListValue(const OUString& 
valueName, sal_Int32** pValue
     sal_uInt32 len = 0;
     readUINT32(pBuffer.get(), len);
 
-    /* make sure the declared size of the arry is consistent with the amount 
of data we have read */
+    /* make sure the declared size of the array is consistent with the amount 
of data we have read */
     if(len > (valueSize - 4) / 4)
     {
         pValueList = nullptr;
_______________________________________________
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits

Reply via email to
diff --git a/qadevOOo/tests/java/ifc/text/_XTextRangeCompare.java 
b/qadevOOo/tests/java/ifc/text/_XTextRangeCompare.java
index 4dedd74cf6d9..47d389c9a4af 100644
--- a/qadevOOo/tests/java/ifc/text/_XTextRangeCompare.java
+++ b/qadevOOo/tests/java/ifc/text/_XTextRangeCompare.java
@@ -67,7 +67,7 @@ public class _XTextRangeCompare extends MultiMethodTest {
     /**
      * Retrieves <code>XText</code> interface from relation 'TEXTDOC'
      * or from 'TEXT'.
      * @throws StatusException If neither 'TEXTDOC' nore 'TEXT'
      * relation exists.
      */
     @Override
@@ -87,7 +87,7 @@ public class _XTextRangeCompare extends MultiMethodTest {
 
         if (oText == null) {
             throw new StatusException(Status.failed
-                ("Neither 'TEXTDOC' nore 'TEXT' relation not found")) ;
+                ("Neither 'TEXTDOC' nor 'TEXT' relation not found")) ;
         }
     }
 
@@ -67,7 +67,7 @@ public class _XTextRangeCompare extends MultiMethodTest {
      * Retrieves <code>XText</code> interface from relation 'TEXTDOC'
      * or from 'TEXT'.
-     * @throws StatusException If neither 'TEXTDOC' nore 'TEXT'
+     * @throws StatusException If neither 'TEXTDOC' nor 'TEXT'
      * relation exists.
      */